@@ -14,6 +14,7 @@ pcl::cloud_composer::CloudItem::CloudItem (QString name,
                                            const Eigen::Quaternionf& orientation,
                                            bool make_templated_cloud)
   : CloudComposerItem (std::move(name))
+  , cloud_blob_ptr_ (cloud_ptr)
   , origin_ (origin)
   , orientation_ (orientation)
   , template_cloud_set_ (false)
@@ -25,7 +26,6 @@ pcl::cloud_composer::CloudItem::CloudItem (QString name,
  // qDebug () << "Cloud size before passthrough : "<<cloud_ptr->width<<"x"<<cloud_ptr->height;
 
 //  qDebug () << "Cloud size after passthrough : "<<cloud_filtered->width<<"x"<<cloud_filtered->height;
-  cloud_blob_ptr_ = cloud_ptr;
   pcl::PCLPointCloud2::ConstPtr const_cloud_ptr = cloud_ptr;
   this->setData (QVariant::fromValue (const_cloud_ptr), ItemDataRole::CLOUD_BLOB);
   this->setData (QVariant::fromValue (origin_), ItemDataRole::ORIGIN);
