@@ -35,6 +35,7 @@
  *         Christian Potthast (potthast@usc.edu)
  */
 
+#include <pcl/common/pcl_filesystem.h>
 #include <pcl/common/time.h>
 #include <pcl/console/parse.h>
 #include <pcl/console/print.h>
@@ -45,8 +46,6 @@
 #include <pcl/point_cloud.h>
 #include <pcl/point_types.h>
 
-#include <boost/filesystem.hpp>
-
 #include <mutex>
 
 using namespace std::chrono_literals;
@@ -75,7 +74,6 @@ using namespace std::chrono_literals;
 #endif
 
 using namespace pcl::console;
-using namespace boost::filesystem;
 
 template <typename PointType>
 class OpenNIGrabFrame {
@@ -222,7 +220,7 @@ public:
              bool paused,
              bool visualizer)
   {
-    boost::filesystem::path path(filename);
+    pcl_fs::path path(filename);
 
     if (filename.empty()) {
       dir_name_ = ".";
@@ -231,7 +229,7 @@ public:
     else {
       dir_name_ = path.parent_path().string();
 
-      if (!dir_name_.empty() && !boost::filesystem::exists(path.parent_path())) {
+      if (!dir_name_.empty() && !pcl_fs::exists(path.parent_path())) {
         std::cerr << "directory \"" << path.parent_path() << "\" does not exist!\n";
         exit(1);
       }
