@@ -39,12 +39,11 @@
 #include <pcl/console/print.h>
 #include <pcl/io/openni_grabber.h>
 #include <pcl/io/pcd_io.h>
+#include <pcl/io/timestamp.h>
 #include <pcl/keypoints/harris_2d.h>
 #include <pcl/tracking/pyramidal_klt.h>
 #include <pcl/visualization/image_viewer.h>
 
-#include <boost/date_time/posix_time/posix_time.hpp> // for to_iso_string, local_time
-
 #include <mutex>
 
 #define SHOW_FPS 1
@@ -113,7 +112,7 @@ public:
   using CloudConstPtr = typename Cloud::ConstPtr;
 
   OpenNIViewer(pcl::Grabber& grabber)
-  : grabber_(grabber), rgb_data_(nullptr), rgb_data_size_(0)
+  : grabber_(grabber), rgb_data_(nullptr), rgb_data_size_(0), counter_(0)
   {}
 
   void
@@ -175,9 +174,7 @@ public:
       if ((event.getKeyCode() == 's') || (event.getKeyCode() == 'S')) {
         std::lock_guard<std::mutex> lock(cloud_mutex_);
         frame.str("frame-");
-        frame << boost::posix_time::to_iso_string(
-                     boost::posix_time::microsec_clock::local_time())
-              << ".pcd";
+        frame << pcl::getTimestamp() << ".pcd";
         writer.writeBinaryCompressed(frame.str(), *cloud_);
         PCL_INFO("Written cloud %s.\n", frame.str().c_str());
       }
@@ -312,12 +309,14 @@ main(int argc, char** argv)
   pcl::OpenNIGrabber::Mode image_mode = pcl::OpenNIGrabber::OpenNI_Default_Mode;
   bool xyz = false;
 
+  if (pcl::console::find_argument(argc, argv, "-h") != -1 ||
+      pcl::console::find_argument(argc, argv, "--help") != -1) {
+    printHelp(argc, argv);
+    return 1;
+  }
+
   if (argc >= 2) {
     device_id = argv[1];
-    if (device_id == "--help" || device_id == "-h") {
-      printHelp(argc, argv);
-      return 0;
-    }
     if (device_id == "-l") {
       if (argc >= 3) {
         pcl::OpenNIGrabber grabber(argv[2]);
