@@ -150,9 +150,11 @@ public:
 void
 usage(char** argv)
 {
-  std::cout << "usage: " << argv[0] << " <device_id> <options>\n\n"
-            << "where options are:\n         -thresh X        :: set the planar "
-               "segmentation threshold (default: 0.5)\n";
+  std::cout
+      << "usage: " << argv[0] << " [options]\n\n"
+      << "where options are:\n"
+      << "    -device_id X: specify the device id (default: \"#1\").\n"
+      << "    -thresh X: set the planar segmentation threshold (default: 0.5)\n\n";
 
   openni_wrapper::OpenNIDriver& driver = openni_wrapper::OpenNIDriver::getInstance();
   if (driver.getNumberDevices() > 0) {
@@ -161,10 +163,20 @@ usage(char** argv)
       std::cout << "Device: " << deviceIdx + 1 << ", vendor: " << driver.getVendorName (deviceIdx) << ", product: " << driver.getProductName (deviceIdx)
               << ", connected: " << driver.getBus (deviceIdx) << " @ " << driver.getAddress (deviceIdx) << ", serial number: \'" << driver.getSerialNumber (deviceIdx) << "\'" << std::endl;
       std::cout << "device_id may be #1, #2, ... for the first second etc device in the list or" << std::endl
-           << "                 bus@address for the device connected to a specific usb-bus / address combination (wotks only in Linux) or" << std::endl
+           << "                 bus@address for the device connected to a specific usb-bus / address combination (works only in Linux) or" << std::endl
            << "                 <serial-number> (only in Linux and for devices which provide serial numbers)"  << std::endl;
       // clang-format on
     }
+
+    std::cout << "\ndevice_id may be:" << std::endl
+              << "    #1, #2, ... for the first second etc device in the list or"
+              << std::endl
+
+              << "    bus@address for the device connected to a specific "
+                 "usb-bus/address combination (works only in Linux) or"
+
+              << "    <serial-number> (only in Linux and for devices which provide "
+                 "serial numbers)";
   }
   else
     std::cout << "No devices connected." << std::endl;
@@ -173,28 +185,29 @@ usage(char** argv)
 int
 main(int argc, char** argv)
 {
-  if (argc < 2) {
-    usage(argv);
-    return 1;
-  }
-
-  std::string arg(argv[1]);
-
-  if (arg == "--help" || arg == "-h") {
+  /////////////////////////////////////////////////////////////////////
+  if (pcl::console::find_argument(argc, argv, "-h") != -1 ||
+      pcl::console::find_argument(argc, argv, "--help") != -1) {
     usage(argv);
     return 1;
   }
 
+  std::string device_id = "";
   double threshold = 0.05;
-  pcl::console::parse_argument(argc, argv, "-thresh", threshold);
 
-  pcl::OpenNIGrabber grabber(arg);
+  if (pcl::console::parse_argument(argc, argv, "-device_id", device_id) == -1 &&
+      argc > 1 && argv[1][0] != '-')
+    device_id = argv[1];
+  pcl::console::parse_argument(argc, argv, "-thresh", threshold);
+  /////////////////////////////////////////////////////////////////////
+
+  pcl::OpenNIGrabber grabber(device_id);
   if (grabber.providesCallback<pcl::OpenNIGrabber::sig_cb_openni_point_cloud_rgba>()) {
-    OpenNIPlanarSegmentation<pcl::PointXYZRGBA> v(arg, threshold);
+    OpenNIPlanarSegmentation<pcl::PointXYZRGBA> v(device_id, threshold);
     v.run();
   }
   else {
-    OpenNIPlanarSegmentation<pcl::PointXYZ> v(arg, threshold);
+    OpenNIPlanarSegmentation<pcl::PointXYZ> v(device_id, threshold);
     v.run();
   }
 
