@@ -53,6 +53,7 @@
 
 #include <algorithm>
 #include <iterator>
+#include <numeric> // for accumulate
 
 namespace pcl
 {
@@ -103,7 +104,7 @@ namespace pcl
           }
         }
         // Disable thrown exception per #595: http://dev.pointclouds.org/issues/595
-        PCL_WARN ("Failed to find match for field '%s'.\n", pcl::traits::name<PointT, Tag>::value);
+        PCL_WARN ("Failed to find exact match for field '%s'.\n", pcl::traits::name<PointT, Tag>::value);
         //throw pcl::InvalidConversionException (ss.str ());
       }
 
@@ -117,6 +118,71 @@ namespace pcl
       return (a.serialized_offset < b.serialized_offset);
     }
 
+    // Helps converting PCLPointCloud2 to templated point cloud. Casts fields if datatype is different.
+    template<typename PointT>
+    struct FieldCaster
+    {
+      FieldCaster (const std::vector<pcl::PCLPointField>& fields, const pcl::PCLPointCloud2& msg, const std::uint8_t* msg_data, std::uint8_t* cloud_data)
+        : fields_ (fields), msg_(msg), msg_data_(msg_data), cloud_data_(cloud_data)
+      {}
+
+      template<typename Tag> void
+      operator () ()
+      {
+        // first check whether any field matches exactly. Then there is nothing to do because the contents are memcpy-ed elsewhere
+        for (const auto& field : fields_) {
+          if (FieldMatches<PointT, Tag>()(field)) {
+            return;
+          }
+        }
+        for (const auto& field : fields_)
+        {
+          // The following check is similar to FieldMatches, but it tests for different datatypes
+          if ((field.name == pcl::traits::name<PointT, Tag>::value) &&
+              (field.datatype != pcl::traits::datatype<PointT, Tag>::value) &&
+              ((field.count == pcl::traits::datatype<PointT, Tag>::size) ||
+               (field.count == 0 && pcl::traits::datatype<PointT, Tag>::size == 1))) {
+#define PCL_CAST_POINT_FIELD(TYPE) case ::pcl::traits::asEnum_v<TYPE>: \
+            PCL_WARN("Will try to cast field '%s' (original type is " #TYPE "). You may loose precision during casting. Make sure that this is acceptable or choose a different point type.\n", pcl::traits::name<PointT, Tag>::value); \
+            for (std::size_t row = 0; row < msg_.height; ++row) { \
+              const std::uint8_t* row_data = msg_data_ + row * msg_.row_step; \
+              for (std::size_t col = 0; col < msg_.width; ++col) { \
+                const std::uint8_t* msg_data = row_data + col * msg_.point_step; \
+                for(std::uint32_t i=0; i<pcl::traits::datatype<PointT, Tag>::size; ++i) { \
+                  *(reinterpret_cast<typename pcl::traits::datatype<PointT, Tag>::decomposed::type*>(cloud_data + pcl::traits::offset<PointT, Tag>::value) + i) = *(reinterpret_cast<const TYPE*>(msg_data + field.offset) + i); \
+                } \
+                cloud_data += sizeof (PointT); \
+              } \
+            } \
+            break;
+            // end of PCL_CAST_POINT_FIELD definition
+
+            std::uint8_t* cloud_data = cloud_data_;
+            switch(field.datatype) {
+              PCL_CAST_POINT_FIELD(bool)
+              PCL_CAST_POINT_FIELD(std::int8_t)
+              PCL_CAST_POINT_FIELD(std::uint8_t)
+              PCL_CAST_POINT_FIELD(std::int16_t)
+              PCL_CAST_POINT_FIELD(std::uint16_t)
+              PCL_CAST_POINT_FIELD(std::int32_t)
+              PCL_CAST_POINT_FIELD(std::uint32_t)
+              PCL_CAST_POINT_FIELD(std::int64_t)
+              PCL_CAST_POINT_FIELD(std::uint64_t)
+              PCL_CAST_POINT_FIELD(float)
+              PCL_CAST_POINT_FIELD(double)
+              default: std::cout << "Unknown datatype: " << field.datatype << std::endl;
+            }
+            return;
+          }
+#undef PCL_CAST_POINT_FIELD
+        }
+      }
+
+      const std::vector<pcl::PCLPointField>& fields_;
+      const pcl::PCLPointCloud2& msg_;
+      const std::uint8_t* msg_data_;
+      std::uint8_t* cloud_data_;
+    };
   } //namespace detail
 
   template<typename PointT> void
@@ -175,7 +241,6 @@ namespace pcl
     // check if there is data to copy
     if (msg.width * msg.height == 0)
     {
-      PCL_WARN("[pcl::fromPCLPointCloud2] No data to copy.\n");
       return;
     }
 
@@ -222,6 +287,9 @@ namespace pcl
         }
       }
     }
+    // if any fields in msg and cloud have different datatypes but the same name, we cast them:
+    detail::FieldCaster<PointT> caster (msg.fields, msg, msg_data, reinterpret_cast<std::uint8_t*>(cloud.data()));
+    for_each_type< typename traits::fieldList<PointT>::type > (caster);
   }
 
   /** \brief Convert a PCLPointCloud2 binary data blob into a pcl::PointCloud<T> object using a field_map.
@@ -256,12 +324,52 @@ namespace pcl
     fromPCLPointCloud2 (msg, cloud, field_map);
   }
 
+  namespace detail {
+    /** \brief Used together with `pcl::for_each_type`, copies all point fields from `cloud_data` (respecting each field offset) to `msg_data` (tightly packed).
+      */
+    template<typename PointT>
+    struct FieldCopier {
+      FieldCopier(std::uint8_t*& msg_data, const std::uint8_t*& cloud_data) : msg_data_ (msg_data), cloud_data_ (cloud_data) {};
+
+      template<typename U> void operator() () {
+        memcpy(msg_data_, cloud_data_ + pcl::traits::offset<PointT, U>::value, sizeof(typename pcl::traits::datatype<PointT, U>::type));
+        msg_data_ += sizeof(typename pcl::traits::datatype<PointT, U>::type);
+      }
+
+      std::uint8_t*& msg_data_;
+      const std::uint8_t*& cloud_data_;
+    };
+
+    /** \brief Used together with `pcl::for_each_type`, creates list of all fields, and list of size of each field.
+      */
+    template<typename PointT>
+    struct FieldAdderAdvanced
+    {
+      FieldAdderAdvanced (std::vector<pcl::PCLPointField>& fields, std::vector<std::size_t>& field_sizes) : fields_ (fields), field_sizes_ (field_sizes) {};
+
+      template<typename U> void operator() ()
+      {
+        pcl::PCLPointField f;
+        f.name = pcl::traits::name<PointT, U>::value;
+        f.offset = pcl::traits::offset<PointT, U>::value;
+        f.datatype = pcl::traits::datatype<PointT, U>::value;
+        f.count = pcl::traits::datatype<PointT, U>::size;
+        fields_.push_back (f);
+        field_sizes_.push_back (sizeof(typename pcl::traits::datatype<PointT, U>::type)); // If field is an array, then this is the size of all array elements
+      }
+
+      std::vector<pcl::PCLPointField>& fields_;
+      std::vector<std::size_t>& field_sizes_;
+    };
+  } // namespace detail
+
   /** \brief Convert a pcl::PointCloud<T> object to a PCLPointCloud2 binary data blob.
     * \param[in] cloud the input pcl::PointCloud<T>
     * \param[out] msg the resultant PCLPointCloud2 binary blob
+    * \param[in] padding Many point types have padding to ensure alignment and SIMD compatibility. Setting this to true will copy the padding to the `PCLPointCloud2` (the default in older PCL versions). Setting this to false will make the data blob in `PCLPointCloud2` smaller, while still keeping all information (useful e.g. when sending msg over network or storing it). The amount of padding depends on the point type, and can in some cases be up to 50 percent.
     */
   template<typename PointT> void
-  toPCLPointCloud2 (const pcl::PointCloud<PointT>& cloud, pcl::PCLPointCloud2& msg)
+  toPCLPointCloud2 (const pcl::PointCloud<PointT>& cloud, pcl::PCLPointCloud2& msg, bool padding)
   {
     // Ease the user's burden on specifying width/height for unorganized datasets
     if (cloud.width == 0 && cloud.height == 0)
@@ -275,26 +383,55 @@ namespace pcl
       msg.height = cloud.height;
       msg.width  = cloud.width;
     }
-
-    // Fill point cloud binary data (padding and all)
-    std::size_t data_size = sizeof (PointT) * cloud.size ();
-    msg.data.resize (data_size);
-    if (data_size)
-    {
-      memcpy(msg.data.data(), cloud.data(), data_size);
-    }
-
     // Fill fields metadata
     msg.fields.clear ();
-    for_each_type<typename traits::fieldList<PointT>::type> (detail::FieldAdder<PointT>(msg.fields));
+    std::vector<std::size_t> field_sizes;
+    for_each_type<typename pcl::traits::fieldList<PointT>::type>(pcl::detail::FieldAdderAdvanced<PointT>(msg.fields, field_sizes));
+    // Check if padding should be kept, or if the point type does not contain padding (then the single memcpy is faster)
+    if (padding || std::accumulate(field_sizes.begin(), field_sizes.end(), static_cast<std::size_t>(0)) == sizeof (PointT)) {
+      // Fill point cloud binary data (padding and all)
+      std::size_t data_size = sizeof (PointT) * cloud.size ();
+      msg.data.resize (data_size);
+      if (data_size)
+      {
+        memcpy(msg.data.data(), cloud.data(), data_size);
+      }
 
+      msg.point_step = sizeof (PointT);
+      msg.row_step   = (sizeof (PointT) * msg.width);
+    } else {
+      std::size_t point_size = 0;
+      for(std::size_t i=0; i<msg.fields.size(); ++i) {
+        msg.fields[i].offset = point_size; // Adjust offset when padding is removed
+        point_size += field_sizes[i];
+      }
+      msg.data.resize (point_size * cloud.size());
+      std::uint8_t* msg_data = &msg.data[0];
+      const std::uint8_t* cloud_data=reinterpret_cast<const std::uint8_t*>(&cloud[0]);
+      const std::uint8_t* end = cloud_data + sizeof (PointT) * cloud.size ();
+      pcl::detail::FieldCopier<PointT> copier(msg_data, cloud_data); // copier takes msg_data and cloud_data as references, so the two are shared
+      for (; cloud_data<end; cloud_data+=sizeof(PointT)) {
+        for_each_type< typename traits::fieldList<PointT>::type > (copier);
+      }
+
+      msg.point_step = point_size;
+      msg.row_step   = point_size * msg.width;
+    }
     msg.header     = cloud.header;
-    msg.point_step = sizeof (PointT);
-    msg.row_step   = (sizeof (PointT) * msg.width);
     msg.is_dense   = cloud.is_dense;
     /// @todo msg.is_bigendian = ?;
   }
 
+  /** \brief Convert a pcl::PointCloud<T> object to a PCLPointCloud2 binary data blob.
+    * \param[in] cloud the input pcl::PointCloud<T>
+    * \param[out] msg the resultant PCLPointCloud2 binary blob
+    */
+  template<typename PointT> void
+  toPCLPointCloud2 (const pcl::PointCloud<PointT>& cloud, pcl::PCLPointCloud2& msg)
+  {
+    toPCLPointCloud2 (cloud, msg, true); // true is the default in older PCL version
+  }
+
    /** \brief Copy the RGB fields of a PointCloud into pcl::PCLImage format
      * \param[in] cloud the point cloud message
      * \param[out] msg the resultant pcl::PCLImage
