@@ -86,7 +86,11 @@ main (int argc, char ** argv)
   
   //Parse filter parameters
   std::string filter_parameters_file;
-  pcl::console::parse_argument (argc, argv, "--filter", filter_parameters_file) > 0;    
+  if (pcl::console::parse_argument (argc, argv, "--filter", filter_parameters_file) < 0)
+  {
+    pcl::console::print_error ("Missing option --filter\n");
+    return (1);
+  }
   input_stream.open (filter_parameters_file.c_str ());
   if (input_stream.is_open())
   {
@@ -105,7 +109,11 @@ main (int argc, char ** argv)
   
   // Parse segmentation parameters
   std::string segmentation_parameters_file;
-  pcl::console::parse_argument (argc, argv, "--segment", segmentation_parameters_file) > 0;    
+  if (pcl::console::parse_argument (argc, argv, "--segment", segmentation_parameters_file) < 0)
+  {
+    pcl::console::print_error ("Missing option --segment\n");
+    return (1);
+  }
   input_stream.open (segmentation_parameters_file.c_str ());
   if (input_stream.is_open())
   {
@@ -125,7 +133,11 @@ main (int argc, char ** argv)
 
   // Parse feature estimation parameters
   std::string feature_estimation_parameters_file;
-  pcl::console::parse_argument (argc, argv, "--feature", feature_estimation_parameters_file) > 0;    
+  if (pcl::console::parse_argument (argc, argv, "--feature", feature_estimation_parameters_file) < 0)
+  {
+    pcl::console::print_error ("Missing option --feature\n");
+    return (1);
+  }
   input_stream.open (feature_estimation_parameters_file.c_str ());
   if (input_stream.is_open())
   {
@@ -146,7 +158,11 @@ main (int argc, char ** argv)
 
   // Parse the registration parameters
   std::string registration_parameters_file;
-  pcl::console::parse_argument (argc, argv, "--registration", registration_parameters_file) > 0;    
+  if (pcl::console::parse_argument (argc, argv, "--registration", registration_parameters_file) < 0)
+  {
+    pcl::console::print_error ("Missing option --registration\n");
+    return (1);
+  }
   input_stream.open (registration_parameters_file.c_str ());
   if (input_stream.is_open())
   {
