@@ -3,7 +3,7 @@
 #include <pcl/point_types.h>
 
 int
-main (int argc, char** argv)
+main ()
 {
   pcl::PointCloud<pcl::PointXYZ>::Ptr cloud (new pcl::PointCloud<pcl::PointXYZ>);
 
