@@ -4,7 +4,7 @@
 #include <pcl/filters/statistical_outlier_removal.h>
 
 int
-main (int argc, char** argv)
+main ()
 {
   pcl::PointCloud<pcl::PointXYZ>::Ptr cloud (new pcl::PointCloud<pcl::PointXYZ>);
   pcl::PointCloud<pcl::PointXYZ>::Ptr cloud_filtered (new pcl::PointCloud<pcl::PointXYZ>);
@@ -35,4 +35,4 @@ main (int argc, char** argv)
   writer.write<pcl::PointXYZ> ("table_scene_lms400_outliers.pcd", *cloud_filtered, false);
 
   return (0);
-}
\ No newline at end of file
+}
