@@ -29,8 +29,6 @@ class FeatureCloud
       feature_radius_ (0.02f)
     {}
 
-    ~FeatureCloud () {}
-
     // Process the given cloud
     void
     setInputCloud (PointCloud::Ptr xyz)
@@ -140,8 +138,6 @@ class TemplateAlignment
       sac_ia_.setMaximumIterations (nr_iterations_);
     }
 
-    ~TemplateAlignment () {}
-
     // Set the given cloud as the target to which the templates will be aligned
     void
     setTargetCloud (FeatureCloud &target_cloud)
