@@ -3,8 +3,6 @@
 #include <pcl/surface/on_nurbs/fitting_curve_2d_sdm.h>
 #include <pcl/surface/on_nurbs/triangulation.h>
 
-#include <pcl/point_cloud.h>
-#include <pcl/point_types.h>
 #include <pcl/io/pcd_io.h>
 
 #include <pcl/visualization/pcl_visualizer.h>
