@@ -77,9 +77,7 @@ namespace pcl
       }
 
       /** \brief Destructor. */
-      ~GridMinimum ()
-      {
-      }
+      ~GridMinimum () override = default;
 
       /** \brief Set the grid resolution.
         * \param[in] resolution the grid resolution
