@@ -61,7 +61,7 @@ namespace pcl
     using PointCloudPtr = typename PointCloud::Ptr;
     using PointCloudConstPtr = typename PointCloud::ConstPtr;
 
-    using Vector = Eigen::Matrix<float, Eigen::Dynamic, 1>;
+    using Vector = Eigen::Matrix<float, 3, 1>;
 
     public:
 
@@ -69,8 +69,7 @@ namespace pcl
       using ConstPtr = shared_ptr<const SamplingSurfaceNormal<PointT> >;
 
       /** \brief Empty constructor. */
-      SamplingSurfaceNormal () : 
-        sample_ (10), seed_ (static_cast<unsigned int> (time (nullptr))), ratio_ ()
+      SamplingSurfaceNormal ()
       {
         filter_name_ = "SamplingSurfaceNormal";
         srand (seed_);
@@ -128,11 +127,11 @@ namespace pcl
     protected:
 
       /** \brief Maximum number of samples in each grid. */
-      unsigned int sample_;
+      unsigned int sample_{10};
       /** \brief Random number seed. */
-      unsigned int seed_;
+      unsigned int seed_{static_cast<unsigned int> (time (nullptr))};
       /** \brief Ratio of points to be sampled in each grid */
-      float ratio_;
+      float ratio_{0.0f};
 
       /** \brief Sample of point indices into a separate PointCloud
         * \param[out] output the resultant point cloud
