@@ -90,7 +90,7 @@ main (int argc, char** argv)
     std::vector<Eigen::Vector3f, Eigen::aligned_allocator<Eigen::Vector3f> > transforms;
   
     //Get world as a vector of cubes 
-    wm.getWorldAsCubes (pcl::device::kinfuLS::VOLUME_X, clouds, transforms, 0.025); // 2.5% overlapp (12 cells with a 512-wide cube)
+    wm.getWorldAsCubes (pcl::device::kinfuLS::VOLUME_X, clouds, transforms, 0.025); // 2.5% overlap (12 cells with a 512-wide cube)
 
     //Creating the standalone marching cubes instance
     float volume_size = pcl::device::kinfuLS::VOLUME_SIZE;
