@@ -36,18 +36,17 @@
  *  Author: Raphael Favier, Technical University Eindhoven, (r.mysurname <aT> tue.nl)
  */
 
-
-#include <boost/filesystem.hpp>
-
 #include <fstream>
 #include <iostream>
 #include <sstream>
 
+#include <pcl/common/pcl_filesystem.h>
 #include <pcl/common/transforms.h>
 #include <pcl/features/normal_3d.h>
 #include <pcl/visualization/pcl_visualizer.h>
 #include <pcl/surface/texture_mapping.h>
 #include <pcl/io/vtk_lib_io.h>
+#include <pcl/io/ply_io.h>
 
 using namespace pcl;
 
@@ -348,8 +347,8 @@ std::ifstream& GotoLine(std::ifstream& file, unsigned int num)
 /** \brief Helper function that reads a camera file outputted by Kinfu */
 bool readCamPoseFile(std::string filename, pcl::TextureMapping<pcl::PointXYZ>::Camera &cam)
 {
-  ifstream myReadFile;
-  myReadFile.open(filename.c_str (), ios::in);
+  std::ifstream myReadFile;
+  myReadFile.open(filename.c_str (), std::ios::in);
   if(!myReadFile.is_open ())
   {
     PCL_ERROR ("Error opening file %d\n", filename.c_str ());
@@ -405,7 +404,7 @@ main (int argc, char** argv)
   // read mesh from plyfile
   PCL_INFO ("\nLoading mesh from file %s...\n", argv[1]);
   pcl::PolygonMesh triangles;
-  pcl::io::loadPolygonFilePLY(argv[1], triangles);
+  pcl::io::loadPLYFile(argv[1], triangles);
 
   pcl::PointCloud<pcl::PointXYZ>::Ptr cloud (new pcl::PointCloud<pcl::PointXYZ>);
   pcl::fromPCLPointCloud2(triangles.cloud, *cloud);
@@ -422,26 +421,28 @@ main (int argc, char** argv)
     polygon_1[i] = triangles.polygons[i];
   }
   mesh.tex_polygons.push_back(polygon_1);
-  PCL_INFO ("\tInput mesh contains %d faces and %d vertices\n", mesh.tex_polygons[0].size (), cloud->points.size ());
+  PCL_INFO("\tInput mesh contains %zu faces and %zu vertices\n",
+           mesh.tex_polygons[0].size(),
+           static_cast<std::size_t>(cloud->size()));
   PCL_INFO ("...Done.\n");
   
   // Load textures and cameras poses and intrinsics
   PCL_INFO ("\nLoading textures and camera poses...\n");
   pcl::texture_mapping::CameraVector my_cams;
   
-  const boost::filesystem::path base_dir (".");
+  const pcl_fs::path base_dir (".");
   std::string extension (".txt");
-  for (boost::filesystem::directory_iterator it (base_dir); it != boost::filesystem::directory_iterator (); ++it)
+  for (pcl_fs::directory_iterator it (base_dir); it != pcl_fs::directory_iterator (); ++it)
   {
-    if(boost::filesystem::is_regular_file (it->status ()) && boost::filesystem::extension (it->path ()) == extension)
+    if(pcl_fs::is_regular_file (it->status ()) && it->path ().extension ().string () == extension)
     {
       pcl::TextureMapping<pcl::PointXYZ>::Camera cam;
       readCamPoseFile(it->path ().string (), cam);
-      cam.texture_file = boost::filesystem::basename (it->path ()) + ".png";
+      cam.texture_file = it->path ().stem ().string () + ".png";
       my_cams.push_back (cam);
     }
   }
-  PCL_INFO ("\tLoaded %d textures.\n", my_cams.size ());
+  PCL_INFO ("\tLoaded %zu textures.\n", my_cams.size ());
   PCL_INFO ("...Done.\n");
   
   // Display cameras to user
@@ -492,7 +493,7 @@ main (int argc, char** argv)
   PCL_INFO ("Sorting faces by cameras done.\n");
   for(std::size_t i = 0 ; i <= my_cams.size() ; ++i)
   {
-    PCL_INFO ("\tSub mesh %d contains %d faces and %d UV coordinates.\n", i, mesh.tex_polygons[i].size (), mesh.tex_coordinates[i].size ());
+    PCL_INFO ("\tSub mesh %zu contains %zu faces and %zu UV coordinates.\n", i, mesh.tex_polygons[i].size (), mesh.tex_coordinates[i].size ());
   }
 
 
