@@ -133,8 +133,6 @@ namespace pcl
       public:
         /** \brief Constructor with default values, allocates multilmap device memory **/
         MultiTreeLiveProc(int def_rows = 480, int def_cols = 640) : multilmap (def_rows, def_cols) {}
-        /** \brief Empty destructor **/
-        ~MultiTreeLiveProc() {}
 
         void
         process (const Depth& dmap, Labels& lmap);
@@ -162,9 +160,6 @@ namespace pcl
           //PCL_DEBUG("[pcl::device::ProbabilityProc:ProbabilityProc] : (D) : Constructor called");
         }
 
-        /** \brief Default destructor **/
-        ~ProbabilityProc() {}
-
         /** \brief This will merge the votes from the different trees into one final vote, including probabilistic's **/
         void
         CUDA_SelectLabel ( const Depth& depth, Labels& labels, LabelProbability& probabilities);
