@@ -96,7 +96,7 @@ pcl::gpu::people::PeopleDetector::allocate_buffers(int rows, int cols)
 
   cloud_host_.width  = cols;
   cloud_host_.height = rows;
-  cloud_host_.points.resize(cols * rows);
+  cloud_host_.resize(cols * rows);
   cloud_host_.is_dense = false;
 
   cloud_host_color_.width = cols;
@@ -106,17 +106,17 @@ pcl::gpu::people::PeopleDetector::allocate_buffers(int rows, int cols)
 
   hue_host_.width  = cols;
   hue_host_.height = rows;
-  hue_host_.points.resize(cols * rows);
+  hue_host_.resize(cols * rows);
   hue_host_.is_dense = false;
 
   depth_host_.width  = cols;
   depth_host_.height = rows;
-  depth_host_.points.resize(cols * rows);
+  depth_host_.resize(cols * rows);
   depth_host_.is_dense = false;
 
   flowermat_host_.width  = cols;
   flowermat_host_.height = rows;
-  flowermat_host_.points.resize(cols * rows);
+  flowermat_host_.resize(cols * rows);
   flowermat_host_.is_dense = false;
   
   cloud_device_.create(rows, cols);
@@ -193,9 +193,9 @@ pcl::gpu::people::PeopleDetector::process ()
     Tree2 t;
     buildTree(sorted, cloud_host_, Neck, c, t);
     
-    const std::vector<int>& seed = t.indices.indices;
+    const auto& seed = t.indices.indices;
         
-    std::fill(flowermat_host_.points.begin(), flowermat_host_.points.end(), 0);
+    std::fill(flowermat_host_.begin(), flowermat_host_.end(), 0);
     {
       //ScopeTime time("shs");    
       shs5(cloud_host_, seed, &flowermat_host_[0]);
@@ -332,9 +332,9 @@ pcl::gpu::people::PeopleDetector::processProb ()
     Tree2 t;
     buildTree(sorted, cloud_host_, Neck, c, t, person_attribs_);
 
-    const std::vector<int>& seed = t.indices.indices;
+    const auto& seed = t.indices.indices;
 
-    std::fill(flowermat_host_.points.begin(), flowermat_host_.points.end(), 0);
+    std::fill(flowermat_host_.begin(), flowermat_host_.end(), 0);
     {
       //ScopeTime time("shs");
       shs5(cloud_host_, seed, &flowermat_host_[0]);
@@ -473,7 +473,7 @@ namespace
 }
 
 void 
-pcl::gpu::people::PeopleDetector::shs5(const pcl::PointCloud<PointT> &cloud, const std::vector<int>& indices, unsigned char *mask)
+pcl::gpu::people::PeopleDetector::shs5(const pcl::PointCloud<PointT> &cloud, const pcl::Indices& indices, unsigned char *mask)
 {
   pcl::device::Intr intr(fx_, fy_, cx_, cy_);
   intr.setDefaultPPIfIncorrect(cloud.width, cloud.height);
