@@ -55,8 +55,7 @@ pcl::io::ImageRGB24::ImageRGB24 (FrameWrapper::Ptr image_metadata, Timestamp tim
 {}
 
 
-pcl::io::ImageRGB24::~ImageRGB24 () noexcept
-{}
+pcl::io::ImageRGB24::~ImageRGB24 () noexcept = default;
 
 bool
 pcl::io::ImageRGB24::isResizingSupported (unsigned input_width, unsigned input_height, unsigned output_width, unsigned output_height) const
@@ -82,7 +81,7 @@ pcl::io::ImageRGB24::fillGrayscale (unsigned width, unsigned height, unsigned ch
     unsigned dst_skip = gray_line_step - width; // skip of padding values in bytes
 
     unsigned char* dst_line = gray_buffer;
-    const RGB888Pixel* src_line = (RGB888Pixel*) wrapper_->getData ();
+    const auto* src_line = reinterpret_cast<const RGB888Pixel*>(wrapper_->getData ());
 
     for (unsigned yIdx = 0; yIdx < height; ++yIdx, src_line += src_skip, dst_line += dst_skip)
     {
@@ -110,17 +109,17 @@ pcl::io::ImageRGB24::fillRGB (unsigned width, unsigned height, unsigned char* rg
   if (width == wrapper_->getWidth () && height == wrapper_->getHeight ())
   {
     unsigned line_size = width * 3;
+    const auto* src_line = static_cast<const unsigned char*> (wrapper_->getData ());
     if (rgb_line_step == 0 || rgb_line_step == line_size)
     {
-      memcpy (rgb_buffer, wrapper_->getData (), wrapper_->getDataSize ());
+      std::copy(src_line, src_line + wrapper_->getDataSize(), rgb_buffer);
     }
     else // line by line
     {
       unsigned char* rgb_line = rgb_buffer;
-      const unsigned char* src_line = static_cast<const unsigned char*> (wrapper_->getData ());
       for (unsigned yIdx = 0; yIdx < height; ++yIdx, rgb_line += rgb_line_step, src_line += line_size)
       {
-        memcpy (rgb_line, src_line, line_size);
+        std::copy(src_line, src_line + line_size, rgb_line);
       }
     }
   }
@@ -134,8 +133,8 @@ pcl::io::ImageRGB24::fillRGB (unsigned width, unsigned height, unsigned char* rg
 
     unsigned dst_skip = rgb_line_step - width * 3; // skip of padding values in bytes
 
-    RGB888Pixel* dst_line = reinterpret_cast<RGB888Pixel*> (rgb_buffer);
-    const RGB888Pixel* src_line = (RGB888Pixel*) wrapper_->getData ();
+    auto* dst_line = reinterpret_cast<RGB888Pixel*> (rgb_buffer);
+    const auto* src_line = reinterpret_cast<const RGB888Pixel*> (wrapper_->getData ());
 
     for (unsigned yIdx = 0; yIdx < height; ++yIdx, src_line += src_skip)
     {
@@ -147,7 +146,7 @@ pcl::io::ImageRGB24::fillRGB (unsigned width, unsigned height, unsigned char* rg
       if (dst_skip != 0)
       {
         // use bytes to skip rather than XnRGB24Pixel's, since line_step does not need to be multiple of 3
-        unsigned char* temp = reinterpret_cast <unsigned char*> (dst_line);
+        auto* temp = reinterpret_cast <unsigned char*> (dst_line);
         dst_line = reinterpret_cast <RGB888Pixel*> (temp + dst_skip);
       }
     }
