@@ -82,7 +82,7 @@ namespace pcl
             }
           }
 
-          ~OpenNI2DeviceListener ()
+          ~OpenNI2DeviceListener () override
           {
             openni::OpenNI::removeDeviceConnectedListener (this);
             openni::OpenNI::removeDeviceDisconnectedListener (this);
@@ -136,11 +136,9 @@ namespace pcl
 
             result->reserve (device_set_.size ());
 
-            std::set<OpenNI2DeviceInfo, OpenNI2DeviceInfoComparator>::const_iterator it;
-            std::set<OpenNI2DeviceInfo, OpenNI2DeviceInfoComparator>::const_iterator it_end = device_set_.end ();
-
-            for (it = device_set_.begin (); it != it_end; ++it)
-              result->push_back (it->uri_);
+            for (const auto& device : device_set_) {
+              result->push_back(device.uri_);
+            }
 
             return result;
           }
@@ -191,9 +189,7 @@ pcl::io::openni2::OpenNI2DeviceManager::OpenNI2DeviceManager ()
   device_listener_.reset(new OpenNI2DeviceListener);
 }
 
-pcl::io::openni2::OpenNI2DeviceManager::~OpenNI2DeviceManager ()
-{
-}
+pcl::io::openni2::OpenNI2DeviceManager::~OpenNI2DeviceManager () = default;
 
 std::shared_ptr<std::vector<OpenNI2DeviceInfo>>
 pcl::io::openni2::OpenNI2DeviceManager::getConnectedDeviceInfos () const
