@@ -47,12 +47,12 @@ template <typename Point1T, typename Point2T> void
 pcl::getApproximateIndices (
     const typename pcl::PointCloud<Point1T>::ConstPtr &cloud_in,
     const typename pcl::PointCloud<Point2T>::ConstPtr &cloud_ref,
-    std::vector<int> &indices)
+    Indices &indices)
 {
   pcl::KdTreeFLANN<Point2T> tree;
   tree.setInputCloud (cloud_ref);
 
-  std::vector<int> nn_idx (1);
+  Indices nn_idx (1);
   std::vector<float> nn_dists (1);
   indices.resize (cloud_in->size ());
   for (std::size_t i = 0; i < cloud_in->size (); ++i)
@@ -67,12 +67,12 @@ template <typename PointT> void
 pcl::getApproximateIndices (
     const typename pcl::PointCloud<PointT>::ConstPtr &cloud_in,
     const typename pcl::PointCloud<PointT>::ConstPtr &cloud_ref,
-    std::vector<int> &indices)
+    Indices &indices)
 {
   pcl::KdTreeFLANN<PointT> tree;
   tree.setInputCloud (cloud_ref);
 
-  std::vector<int> nn_idx (1);
+  Indices nn_idx (1);
   std::vector<float> nn_dists (1);
   indices.resize (cloud_in->size ());
   for (std::size_t i = 0; i < cloud_in->size (); ++i)
