@@ -67,10 +67,10 @@ public:
                                                                     NodeType>>;
 
   /** Constructor. */
-  DecisionTreeTrainerDataProvider() {}
+  DecisionTreeTrainerDataProvider() = default;
 
   /** Destructor. */
-  ~DecisionTreeTrainerDataProvider() {}
+  virtual ~DecisionTreeTrainerDataProvider() = default;
 
   /** Virtual function called to obtain training examples and labels before
    *  training a specific tree */
