@@ -82,7 +82,7 @@ public:
   OctreePointCloudAdjacencyContainer() : OctreeContainerBase() { this->reset(); }
 
   /** \brief Empty class deconstructor. */
-  ~OctreePointCloudAdjacencyContainer() {}
+  ~OctreePointCloudAdjacencyContainer() override = default;
 
   /** \brief Returns the number of neighbors this leaf has
    *  \returns number of neighbors
@@ -143,8 +143,7 @@ protected:
   virtual OctreePointCloudAdjacencyContainer*
   deepCopy() const
   {
-    OctreePointCloudAdjacencyContainer* new_container =
-        new OctreePointCloudAdjacencyContainer;
+    auto* new_container = new OctreePointCloudAdjacencyContainer;
     new_container->setNeighbors(this->neighbors_);
     new_container->setPointCounter(this->num_points_);
     return new_container;
@@ -199,7 +198,7 @@ protected:
   void
   removeNeighbor(OctreePointCloudAdjacencyContainer* neighbor)
   {
-    for (iterator neighb_it = neighbors_.begin(); neighb_it != neighbors_.end();
+    for (auto neighb_it = neighbors_.begin(); neighb_it != neighbors_.end();
          ++neighb_it) {
       if (*neighb_it == neighbor) {
         neighbors_.erase(neighb_it);
