@@ -46,9 +46,9 @@
 #include <ctime>
 
 // Boost
-#include <pcl/outofcore/boost.h>
 #include <boost/random/bernoulli_distribution.hpp>
 #include <boost/random/uniform_int.hpp>
+#include <boost/random/variate_generator.hpp> // for boost::variate_generator
 #include <boost/uuid/uuid_io.hpp>
 
 // PCL
@@ -206,7 +206,7 @@ namespace pcl
         PointT temp;
         //open our file
         FILE* f = fopen (disk_storage_filename_.c_str (), "rbe");
-        assert (f != NULL);
+        assert (f != nullptr);
 
         //seek the right length; 
         int seekret = _fseeki64 (f, idx * sizeof(PointT), SEEK_SET);
@@ -331,7 +331,7 @@ namespace pcl
         std::sort (offsets.begin (), offsets.end ());
 
         FILE* f = fopen (disk_storage_filename_.c_str (), "rbe");
-        assert (f != NULL);
+        assert (f != nullptr);
         PointT p;
         char* loc = reinterpret_cast<char*> (&p);
         
@@ -384,7 +384,7 @@ namespace pcl
         buffcount = count - filecount;
       }
 
-      std::uint64_t filesamp = static_cast<std::uint64_t> (percent * static_cast<double> (filecount));
+      auto filesamp = static_cast<std::uint64_t> (percent * static_cast<double> (filecount));
       
       std::uint64_t buffsamp = (buffcount > 0) ? (static_cast<std::uint64_t > (percent * static_cast<double> (buffcount))) : 0;
 
@@ -430,7 +430,7 @@ namespace pcl
         std::sort (offsets.begin (), offsets.end ());
 
         FILE* f = fopen (disk_storage_filename_.c_str (), "rbe");
-        assert (f != NULL);
+        assert (f != nullptr);
         PointT p;
         char* loc = reinterpret_cast<char*> (&p);
         for (std::uint64_t i = 0; i < filesamp; i++)
