@@ -68,7 +68,7 @@ namespace pcl
         OutofcoreBreadthFirstIterator (OctreeDisk& octree_arg);
 
         
-        ~OutofcoreBreadthFirstIterator ();
+        ~OutofcoreBreadthFirstIterator () override;
       
         OutofcoreBreadthFirstIterator&
         operator++ ();
