@@ -24,7 +24,7 @@ public:
   // Operators
   // -----------------------------------------------------------------------------
   Grid (std::string name, int size = 10, double spacing = 1.0);
-  ~Grid () { }
+  ~Grid () override = default;
 
   // Accessors
   // -----------------------------------------------------------------------------
