@@ -14,13 +14,14 @@ private:
 
   static Scene *instance_;
 
+
+public:
+
   Scene ();
   Scene (const Scene& op) = delete;
   Scene&
   operator= (const Scene& op) = delete;
 
-public:
-
   // Singleton
   static Scene*
   instance ()
@@ -43,7 +44,7 @@ public:
   getCamera (vtkCamera *camera);
 
   Camera*
-  getCamera (std::string name);
+  getCamera (const std::string& name);
 
   // Accessors - Objects
   // -----------------------------------------------------------------------------
@@ -51,7 +52,7 @@ public:
   addObject (Object *object);
 
   Object*
-  getObjectByName (std::string name);
+  getObjectByName (const std::string& name);
 
   std::vector<Object*>
   getObjects ();
