@@ -20,10 +20,11 @@
 
 // Operators
 // -----------------------------------------------------------------------------
-Camera::Camera (std::string name) :
-    Object (name), display_ (false)
+Camera::Camera (std::string name)
+  : Object (name)
+  , camera_ (vtkSmartPointer<vtkCamera>::New ())
+  , display_ (false)
 {
-  camera_ = vtkSmartPointer<vtkCamera>::New ();
   camera_->SetClippingRange(0.0001, 100000);
 
   camera_actor_ = vtkSmartPointer<vtkCameraActor>::New ();
@@ -43,10 +44,11 @@ Camera::Camera (std::string name) :
   hull_actor_->GetProperty ()->SetOpacity (0.25);
 }
 
-Camera::Camera (std::string name, vtkSmartPointer<vtkCamera> camera) :
-    Object (name), display_ (false)
+Camera::Camera (std::string name, vtkSmartPointer<vtkCamera> camera)
+  : Object (name)
+  , camera_ (camera)
+  , display_ (false)
 {
-  camera_ = camera;
   camera_->SetClippingRange(0.0001, 100000);
 
   camera_actor_ = vtkSmartPointer<vtkCameraActor>::New ();
