@@ -39,14 +39,10 @@
 #include <cstddef>
 
 //////////////////////////////////////////////////////////////////////////////////////////////
-pcl::QuantizableModality::QuantizableModality ()
-{
-}
+pcl::QuantizableModality::QuantizableModality () = default;
 
 //////////////////////////////////////////////////////////////////////////////////////////////
-pcl::QuantizableModality::~QuantizableModality ()
-{
-}
+pcl::QuantizableModality::~QuantizableModality () = default;
 
 //////////////////////////////////////////////////////////////////////////////////////////////
 pcl::QuantizedMap::QuantizedMap ()
@@ -68,9 +64,7 @@ pcl::QuantizedMap::QuantizedMap (const std::size_t width, const std::size_t heig
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////
-pcl::QuantizedMap::~QuantizedMap ()
-{
-}
+pcl::QuantizedMap::~QuantizedMap () = default;
 
 //////////////////////////////////////////////////////////////////////////////////////////////
 void
