@@ -40,61 +40,50 @@
 #pragma once
 
 #include <boost/graph/adjacency_list.hpp>
+
 #include <Eigen/StdVector>
+
 #include <list>
 
-namespace boost
-{
+namespace boost {
 
-  struct eigen_vecS
-  {
-  };
+struct eigen_vecS {};
 
-  template <class ValueType>
-    struct container_gen<eigen_vecS, ValueType>
-    {
-      using type = std::vector<ValueType, Eigen::aligned_allocator<ValueType> >;
-    };
+template <class ValueType>
+struct container_gen<eigen_vecS, ValueType> {
+  using type = std::vector<ValueType, Eigen::aligned_allocator<ValueType>>;
+};
 
-  template <>
-    struct parallel_edge_traits<eigen_vecS>
-    {
-      using type = allow_parallel_edge_tag;
-    };
+template <>
+struct parallel_edge_traits<eigen_vecS> {
+  using type = allow_parallel_edge_tag;
+};
 
-  namespace detail
-  {
-    template <>
-      struct is_random_access<eigen_vecS>
-      {
-        enum { value = true };
-        using type = mpl::true_;
-      };
-  }
+namespace detail {
+template <>
+struct is_random_access<eigen_vecS> {
+  enum { value = true };
+  using type = mpl::true_;
+};
+} // namespace detail
 
-  struct eigen_listS
-  {
-  };
+struct eigen_listS {};
 
-  template <class ValueType>
-    struct container_gen<eigen_listS, ValueType>
-    {
-      using type = std::list<ValueType, Eigen::aligned_allocator<ValueType> >;
-    };
+template <class ValueType>
+struct container_gen<eigen_listS, ValueType> {
+  using type = std::list<ValueType, Eigen::aligned_allocator<ValueType>>;
+};
 
-  template <>
-    struct parallel_edge_traits<eigen_listS>
-    {
-      using type = allow_parallel_edge_tag;
-    };
+template <>
+struct parallel_edge_traits<eigen_listS> {
+  using type = allow_parallel_edge_tag;
+};
 
-  namespace detail
-  {
-    template <>
-      struct is_random_access<eigen_listS>
-      {
-        enum { value = false };
-        using type = mpl::false_;
-      };
-  }
-}
+namespace detail {
+template <>
+struct is_random_access<eigen_listS> {
+  enum { value = false };
+  using type = mpl::false_;
+};
+} // namespace detail
+} // namespace boost
