@@ -101,8 +101,18 @@ public:
       point_representation_;
   using CorrespondenceEstimationBase<PointSource, PointTarget, Scalar>::target_indices_;
 
-  using KdTree = pcl::search::KdTree<PointTarget>;
-  using KdTreePtr = typename KdTree::Ptr;
+  using typename CorrespondenceEstimationBase<PointSource, PointTarget, Scalar>::KdTree;
+  using typename CorrespondenceEstimationBase<PointSource, PointTarget, Scalar>::
+      KdTreePtr;
+  using typename CorrespondenceEstimationBase<PointSource, PointTarget, Scalar>::
+      KdTreeConstPtr;
+
+  using typename CorrespondenceEstimationBase<PointSource, PointTarget, Scalar>::
+      KdTreeReciprocal;
+  using typename CorrespondenceEstimationBase<PointSource, PointTarget, Scalar>::
+      KdTreeReciprocalPtr;
+  using typename CorrespondenceEstimationBase<PointSource, PointTarget, Scalar>::
+      KdTreeReciprocalConstPtr;
 
   using PointCloudSource = pcl::PointCloud<PointSource>;
   using PointCloudSourcePtr = typename PointCloudSource::Ptr;
@@ -122,7 +132,7 @@ public:
    * Sets the number of neighbors to be considered in the target point cloud (k_) to 10.
    */
   CorrespondenceEstimationNormalShooting()
-  : source_normals_(), source_normals_transformed_(), k_(10)
+  : source_normals_(), source_normals_transformed_()
   {
     corr_name_ = "CorrespondenceEstimationNormalShooting";
   }
@@ -238,7 +248,7 @@ private:
   NormalsPtr source_normals_transformed_;
 
   /** \brief The number of neighbours to be considered in the target point cloud */
-  unsigned int k_;
+  unsigned int k_{10};
 };
 } // namespace registration
 } // namespace pcl
