@@ -124,8 +124,8 @@ Registration<PointSource, PointTarget, Scalar>::getFitnessScore(
 {
   unsigned int nr_elem =
       static_cast<unsigned int>(std::min(distances_a.size(), distances_b.size()));
-  Eigen::VectorXf map_a = Eigen::VectorXf::Map(&distances_a[0], nr_elem);
-  Eigen::VectorXf map_b = Eigen::VectorXf::Map(&distances_b[0], nr_elem);
+  Eigen::VectorXf map_a = Eigen::VectorXf::Map(distances_a.data(), nr_elem);
+  Eigen::VectorXf map_b = Eigen::VectorXf::Map(distances_b.data(), nr_elem);
   return (static_cast<double>((map_a - map_b).sum()) / static_cast<double>(nr_elem));
 }
 
@@ -145,6 +145,8 @@ Registration<PointSource, PointTarget, Scalar>::getFitnessScore(double max_range
   // For each point in the source dataset
   int nr = 0;
   for (const auto& point : input_transformed) {
+    if (!input_->is_dense && !pcl::isXYZFinite(point))
+      continue;
     // Find its nearest neighbor in the target
     tree_->nearestKSearch(point, 1, nn_indices, nn_dists);
 
@@ -214,4 +216,4 @@ Registration<PointSource, PointTarget, Scalar>::align(PointCloudSource& output,
   deinitCompute();
 }
 
-} // namespace pcl
+} // namespace pcl
\ No newline at end of file
