@@ -126,7 +126,7 @@ public:
     // Prevents unnecessary voxel initiations
     if (resolution_ != resolution) {
       resolution_ = resolution;
-      if (input_) {
+      if (target_) { // init() needs target_
         init();
       }
     }
@@ -175,11 +175,37 @@ public:
    * \return outlier ratio
    */
   inline double
+  getOutlierRatio() const
+  {
+    return outlier_ratio_;
+  }
+
+  /** \brief Get the point cloud outlier ratio.
+   * \return outlier ratio
+   */
+  PCL_DEPRECATED(1,
+                 18,
+                 "The method `getOulierRatio` has been renamed to "
+                 "`getOutlierRatio`.")
+  inline double
   getOulierRatio() const
   {
     return outlier_ratio_;
   }
 
+  /** \brief Set/change the point cloud outlier ratio.
+   * \param[in] outlier_ratio outlier ratio
+   */
+  inline void
+  setOutlierRatio(double outlier_ratio)
+  {
+    outlier_ratio_ = outlier_ratio;
+  }
+
+  PCL_DEPRECATED(1,
+                 18,
+                 "The method `setOulierRatio` has been renamed to "
+                 "`setOutlierRatio`.")
   /** \brief Set/change the point cloud outlier ratio.
    * \param[in] outlier_ratio outlier ratio
    */
@@ -220,6 +246,20 @@ public:
     return nr_iterations_;
   }
 
+  /** \brief Get access to the `VoxelGridCovariance` generated from target cloud
+   * containing point means and covariances. Set the input target cloud before calling
+   * this. Useful for debugging, e.g.
+   * \code
+   * pcl::PointCloud<PointXYZ> visualize_cloud;
+   * ndt.getTargetCells().getDisplayCloud(visualize_cloud);
+   * \endcode
+   */
+  inline const TargetGrid&
+  getTargetCells() const
+  {
+    return target_cells_;
+  }
+
   /** \brief Convert 6 element transformation vector to affine transformation.
    * \param[in] x transformation vector of the form [x, y, z, roll, pitch, yaw]
    * \param[out] trans affine transform corresponding to given transformation
@@ -292,6 +332,10 @@ protected:
     target_cells_.setInputCloud(target_);
     // Initiate voxel structure.
     target_cells_.filter(true);
+    PCL_DEBUG("[pcl::%s::init] Computed voxel structure, got %zu voxels with valid "
+              "normal distributions.\n",
+              getClassName().c_str(),
+              target_cells_.getCentroids()->size());
   }
 
   /** \brief Compute derivatives of likelihood function w.r.t. the
@@ -363,24 +407,6 @@ protected:
   computeHessian(Eigen::Matrix<double, 6, 6>& hessian,
                  const PointCloudSource& trans_cloud);
 
-  /** \brief Compute hessian of likelihood function w.r.t. the transformation
-   * vector.
-   * \note Equation 6.13 [Magnusson 2009].
-   * \param[out] hessian the hessian matrix of the likelihood function
-   * w.r.t. the transformation vector
-   * \param[in] trans_cloud transformed point cloud
-   * \param[in] transform the current transform vector
-   */
-  PCL_DEPRECATED(1, 15, "Parameter `transform` is not required")
-  void
-  computeHessian(Eigen::Matrix<double, 6, 6>& hessian,
-                 const PointCloudSource& trans_cloud,
-                 const Eigen::Matrix<double, 6, 1>& transform)
-  {
-    pcl::utils::ignore(transform);
-    computeHessian(hessian, trans_cloud);
-  }
-
   /** \brief Compute individual point contributions to hessian of likelihood
    * function w.r.t. the transformation vector.
    * \note Equation 6.13 [Magnusson 2009].
