@@ -68,7 +68,9 @@
 #include <pcl/sample_consensus/sac_model_plane.h>
 #include <pcl/sample_consensus/sac_model_sphere.h>
 #include <pcl/sample_consensus/sac_model_normal_sphere.h>
+#define SAC_MODEL_STICK_DONT_WARN_DEPRECATED
 #include <pcl/sample_consensus/sac_model_stick.h>
+#undef SAC_MODEL_STICK_DONT_WARN_DEPRECATED
 #include <pcl/sample_consensus/sac_model_ellipse3d.h>
 
 #include <pcl/memory.h>  // for static_pointer_cast
@@ -118,14 +120,14 @@ pcl::SACSegmentation<PointT>::segment (PointIndices &inliers, ModelCoefficients
     Eigen::VectorXf coeff_refined (model_->getModelSize ());
     model_->optimizeModelCoefficients (inliers.indices, coeff, coeff_refined);
     model_coefficients.values.resize (coeff_refined.size ());
-    memcpy (&model_coefficients.values[0], &coeff_refined[0], coeff_refined.size () * sizeof (float));
+    memcpy (model_coefficients.values.data(), coeff_refined.data(), coeff_refined.size () * sizeof (float));
     // Refine inliers
     model_->selectWithinDistance (coeff_refined, threshold_, inliers.indices);
   }
   else
   {
     model_coefficients.values.resize (coeff.size ());
-    memcpy (&model_coefficients.values[0], &coeff[0], coeff.size () * sizeof (float));
+    memcpy (model_coefficients.values.data(), coeff.data(), coeff.size () * sizeof (float));
   }
 
   deinitCompute ();
@@ -155,6 +157,7 @@ pcl::SACSegmentation<PointT>::initSACModel (const int model_type)
     }
     case SACMODEL_STICK:
     {
+      PCL_WARN ("[pcl::%s::initSACModel] SACMODEL_STICK is deprecated: Use SACMODEL_LINE instead (It will be removed in PCL 1.17)\n", getClassName ().c_str ());
       PCL_DEBUG ("[pcl::%s::initSACModel] Using a model of type: SACMODEL_STICK\n", getClassName ().c_str ());
       model_.reset (new SampleConsensusModelStick<PointT> (input_, *indices_));
       double min_radius, max_radius;
