@@ -3,7 +3,7 @@
 #include <pcl/memory.h>
 #include <pcl/pcl_macros.h>
 
-#include <Eigen/Dense>
+#include <Eigen/Geometry> // for Isometry3d
 #include <Eigen/StdVector>
 
 namespace pcl {
@@ -140,7 +140,7 @@ public:
   Eigen::Vector3d
   getYPR() const
   {
-    return Eigen::Vector3d(yaw_, pitch_, roll_);
+    return {yaw_, pitch_, roll_};
   }
 
 private:
