@@ -7,11 +7,9 @@
 
 #pragma once
 
-#include <boost/shared_ptr.hpp>
-
+#include <pcl/memory.h>
 #include <pcl/pcl_macros.h>
 //#include <pcl/win32_macros.h>
-
 #include <pcl/simulation/camera.h>
 #include <pcl/simulation/model.h>
 
