@@ -86,10 +86,9 @@ pcl::StereoMatching::medianFilter(int radius)
   // TODO: do median filter
   int side = radius * 2 + 1;
 
-  short int* out = new short int[width_ * height_];
-  memset(out, 0, width_ * height_ * sizeof(short int));
+  auto* out = new short int[width_ * height_]{};
 
-  short int* v = new short int[side * side];
+  auto* v = new short int[side * side];
 
   for (int y = radius; y < height_ - radius; y++) {
     for (int x = radius; x < width_ - radius; x++) {
@@ -149,7 +148,7 @@ pcl::StereoMatching::getVisualMap(pcl::PointCloud<pcl::RGB>::Ptr vMap)
         vMap->at(x, y) = invalid_val;
       }
       else {
-        unsigned char val =
+        auto val =
             static_cast<unsigned char>(std::floor(scale * disp_map_[y * width_ + x]));
         vMap->at(x, y).r = val;
         vMap->at(x, y).g = val;
@@ -329,10 +328,10 @@ pcl::StereoMatching::getPointCloud(float u_c,
 }
 
 //////////////////////////////////////////////////////////////////////////////
-pcl::GrayStereoMatching::GrayStereoMatching() {}
+pcl::GrayStereoMatching::GrayStereoMatching() = default;
 
 //////////////////////////////////////////////////////////////////////////////
-pcl::GrayStereoMatching::~GrayStereoMatching() {}
+pcl::GrayStereoMatching::~GrayStereoMatching() = default;
 
 //////////////////////////////////////////////////////////////////////////////
 void
@@ -343,8 +342,7 @@ pcl::GrayStereoMatching::preProcessing(unsigned char* img, unsigned char* pp_img
   int area = n * n;
   int threshold = 31;
 
-  int* v = new int[width_];
-  memset(v, 0, sizeof(int) * width_);
+  int* v = new int[width_]{};
 
   for (int x = 0; x < n; x++)
     for (int y = 0; y < n; y++)
@@ -373,7 +371,7 @@ pcl::GrayStereoMatching::preProcessing(unsigned char* img, unsigned char* pp_img
                        img[(y - radius - 1) * width_ + x + radius];
       sum += v[x + radius] - v[x - radius - 1];
 
-      short int temp = static_cast<short int>(img[y * width_ + x] - (sum / area));
+      auto temp = static_cast<short int>(img[y * width_ + x] - (sum / area));
 
       if (temp < -threshold)
         pp_img[y * width_ + x] = 0;
@@ -401,10 +399,10 @@ pcl::GrayStereoMatching::preProcessing(unsigned char* img, unsigned char* pp_img
 void
 pcl::GrayStereoMatching::imgFlip(unsigned char*& img)
 {
-  unsigned char* temp_row = new unsigned char[width_];
+  auto* temp_row = new unsigned char[width_];
 
   for (int j = 0; j < height_; j++) {
-    memcpy(temp_row, img + j * width_, sizeof(unsigned char) * width_);
+    std::copy(img + j * width_, img + j * width_ + width_, temp_row);
     for (int i = 0; i < width_; i++) {
       img[j * width_ + i] = temp_row[width_ - 1 - i];
     }
@@ -515,7 +513,7 @@ pcl::GrayStereoMatching::compute(unsigned char* ref_img,
     pp_trg_img_ = nullptr;
   }
 
-  memset(disp_map_, 0, sizeof(short int) * height_ * width_);
+  std::fill_n(disp_map_, height_ * width_, 0);
 
   if (is_pre_proc_) {
     preProcessing(ref_img, pp_ref_img_);
