@@ -52,15 +52,7 @@ namespace pcl
   {
     public:
       /** \brief Empty constructor that sets the values of the algorithm parameters to the VTK defaults */
-      MeshSmoothingLaplacianVTK ()
-        : num_iter_ (20)
-        , convergence_ (0.0f)
-        , relaxation_factor_ (0.01f)
-        , feature_edge_smoothing_ (false)
-        , feature_angle_ (45.f)
-        , edge_angle_ (15.f)
-        , boundary_smoothing_ (true)
-      {};
+      MeshSmoothingLaplacianVTK () = default;
 
       /** \brief Set the number of iterations for the smoothing filter.
         * \param[in] num_iter the number of iterations
@@ -185,12 +177,12 @@ namespace pcl
       vtkSmartPointer<vtkPolyData> vtk_polygons_;
 
       /// Parameters
-      int num_iter_;
-      float convergence_;
-      float relaxation_factor_;
-      bool feature_edge_smoothing_;
-      float feature_angle_;
-      float edge_angle_;
-      bool boundary_smoothing_;
+      int num_iter_{20};
+      float convergence_{0.0f};
+      float relaxation_factor_{0.01f};
+      bool feature_edge_smoothing_{false};
+      float feature_angle_{45.f};
+      float edge_angle_{15.f};
+      bool boundary_smoothing_{true};
   };
 }
