@@ -31,11 +31,12 @@
  *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  *  POSSIBILITY OF SUCH DAMAGE.
  *
- * 
+ *
  *
  */
 
 #include <pcl/surface/on_nurbs/sparse_mat.h>
+#include <cstdio> // for printf
 
 using namespace pcl;
 using namespace on_nurbs;
