@@ -52,6 +52,9 @@
 
 #include <type_traits>
 
+using pcl::index_t;
+using pcl::Indices;
+
 ////////////////////////////////////////////////////////////////////////////////
 
 template <class MeshTraitsT>
@@ -89,7 +92,7 @@ class TestMeshConversion : public ::testing::Test
       }
 
       // Faces
-      std::vector <std::uint32_t> face;
+      Indices face;
 
       face.push_back (0);
       face.push_back (1);
@@ -130,8 +133,8 @@ class TestMeshConversion : public ::testing::Test
     }
 
     pcl::PointCloud <pcl::PointXYZRGBNormal> vertices_;
-    std::vector <std::vector <std::uint32_t> >    non_manifold_faces_;
-    std::vector <std::vector <std::uint32_t> >    manifold_faces_;
+    std::vector <Indices>    non_manifold_faces_;
+    std::vector <Indices>    manifold_faces_;
 
   public:
     PCL_MAKE_ALIGNED_OPERATOR_NEW
@@ -163,7 +166,7 @@ TYPED_TEST (TestMeshConversion, HalfEdgeMeshToFaceVertexMesh)
   using VertexIndex = typename Mesh::VertexIndex;
   using VertexIndices = typename Mesh::VertexIndices;
 
-  const std::vector <std::vector <std::uint32_t> > faces =
+  const std::vector <Indices> faces =
       Mesh::IsManifold::value ? this->manifold_faces_ :
                                 this->non_manifold_faces_;
 
@@ -179,7 +182,7 @@ TYPED_TEST (TestMeshConversion, HalfEdgeMeshToFaceVertexMesh)
   for (std::size_t i=0; i<faces.size (); ++i)
   {
     vi.clear ();
-    for (const unsigned int &j : faces [i])
+    for (const auto &j : faces [i])
     {
       vi.push_back (VertexIndex (static_cast <int> (j)));
     }
@@ -268,13 +271,13 @@ TYPED_TEST (TestMeshConversion, FaceVertexMeshToHalfEdgeMesh)
   }
 
   // Check the faces
-  const std::vector <std::vector <std::uint32_t> > expected_faces =
+  const std::vector <Indices> expected_faces =
       Mesh::IsManifold::value ? this->manifold_faces_ :
                                 this->non_manifold_faces_;
 
   ASSERT_EQ (expected_faces.size (), half_edge_mesh.sizeFaces ());
 
-  std::vector <std::uint32_t> converted_face;
+  Indices converted_face;
   for (std::size_t i=0; i<half_edge_mesh.sizeFaces (); ++i)
   {
     VAFC       circ     = half_edge_mesh.getVertexAroundFaceCirculator (FaceIndex (i));
@@ -282,7 +285,7 @@ TYPED_TEST (TestMeshConversion, FaceVertexMeshToHalfEdgeMesh)
     converted_face.clear ();
     do
     {
-      converted_face.push_back (static_cast <std::uint32_t> (circ.getTargetIndex ().get ()));
+      converted_face.push_back (static_cast <index_t> (circ.getTargetIndex ().get ()));
     } while (++circ != circ_end);
 
     EXPECT_TRUE (isCircularPermutation (expected_faces [i], converted_face)) << "Face number " << i;
