@@ -1,9 +1,9 @@
 #pragma once
 
-const int nr_threads = 1;
-const float voxel_size = 0.1f;
-const float approx_overlap = 0.9f;
-const float abort_score = 0.0f;
+constexpr int nr_threads = 1;
+constexpr float voxel_size = 0.1f;
+constexpr float approx_overlap = 0.9f;
+constexpr float abort_score = 0.4f;
 
 const float transformation_office1_office2 [4][4] = {
   { -0.6946f, -0.7194f, -0.0051f, -3.6352f },
