@@ -195,8 +195,8 @@ TEST (PCL, ConvexHull_LTable)
   {
     for (std::size_t j = 0; j <= 2; j++)
     {
-      cloud_out_ltable[npoints].x = float (i) * 0.5f;
-      cloud_out_ltable[npoints].y = -float (j) * 0.5f;
+      cloud_out_ltable[npoints].x = static_cast<float>(i) * 0.5f;
+      cloud_out_ltable[npoints].y = -static_cast<float>(j) * 0.5f;
       cloud_out_ltable[npoints].z = 0.f;
       npoints++;
     }
@@ -206,8 +206,8 @@ TEST (PCL, ConvexHull_LTable)
   {
     for (std::size_t j = 3; j < 8; j++)
     {
-      cloud_out_ltable[npoints].x = float (i) * 0.5f;
-      cloud_out_ltable[npoints].y = -float (j) * 0.5f;
+      cloud_out_ltable[npoints].x = static_cast<float>(i) * 0.5f;
+      cloud_out_ltable[npoints].y = -static_cast<float>(j) * 0.5f;
       cloud_out_ltable[npoints].z = 0.f;
       npoints++;
     }
