@@ -37,18 +37,16 @@
  *
  */
 
-#include <gtest/gtest.h>
+#include <pcl/test/gtest.h>
 
 #include <pcl/point_types.h>
 #include <pcl/io/pcd_io.h>
 #include <pcl/io/vtk_io.h>
 #include <pcl/features/normal_3d.h>
 #include <pcl/surface/organized_fast_mesh.h>
-#include <pcl/common/common.h>
 
 using namespace pcl;
 using namespace pcl::io;
-using namespace std;
 
 PointCloud<PointXYZ>::Ptr cloud (new PointCloud<PointXYZ>);
 PointCloud<PointNormal>::Ptr cloud_with_normals (new PointCloud<PointNormal>);
@@ -75,16 +73,16 @@ TEST (PCL, Organized)
   {
     for (std::size_t j = 0; j < cloud_organized->width; j++)
     {
-      cloud_organized->points[npoints].x = static_cast<float> (i);
-      cloud_organized->points[npoints].y = static_cast<float> (j);
-      cloud_organized->points[npoints].z = static_cast<float> (cloud_organized->points.size ()); // to avoid shadowing
+      (*cloud_organized)[npoints].x = static_cast<float> (i);
+      (*cloud_organized)[npoints].y = static_cast<float> (j);
+      (*cloud_organized)[npoints].z = static_cast<float> (cloud_organized->size ()); // to avoid shadowing
       npoints++;
     }
   }
   int nan_idx = cloud_organized->width*cloud_organized->height - 2*cloud_organized->width + 1;
-  cloud_organized->points[nan_idx].x = std::numeric_limits<float>::quiet_NaN ();
-  cloud_organized->points[nan_idx].y = std::numeric_limits<float>::quiet_NaN ();
-  cloud_organized->points[nan_idx].z = std::numeric_limits<float>::quiet_NaN ();
+  (*cloud_organized)[nan_idx].x = std::numeric_limits<float>::quiet_NaN ();
+  (*cloud_organized)[nan_idx].y = std::numeric_limits<float>::quiet_NaN ();
+  (*cloud_organized)[nan_idx].z = std::numeric_limits<float>::quiet_NaN ();
   
   // Init objects
   PolygonMesh triangles;
