@@ -39,7 +39,6 @@
 #include <pcl/point_types.h>
 #include <pcl/io/oni_grabber.h>
 #include <pcl/io/pcd_io.h>
-#include <vector>
 
 using namespace pcl;
 using namespace pcl::console;
@@ -81,7 +80,7 @@ main (int argc, char **argv)
     return (-1);
   }
 
-  pcl::ONIGrabber* grabber = new pcl::ONIGrabber (argv[1], false, false);
+  auto* grabber = new pcl::ONIGrabber (argv[1], false, false);
   std::function<void (const CloudConstPtr&) > f = [] (const CloudConstPtr& cloud) { cloud_cb (cloud); };
   boost::signals2::connection c = grabber->registerCallback (f);
 
