@@ -53,6 +53,7 @@
 #include <pcl/filters/voxel_grid.h>
 #include <pcl/memory.h>  // for pcl::make_shared
 #include <pcl/point_types.h>
+#include <pcl/common/pcl_filesystem.h>
 #include <pcl/console/parse.h>
 
 #include <vtkGeneralTransform.h>
@@ -64,7 +65,6 @@
 #include <vtkMath.h>
 
 #include <boost/algorithm/string.hpp>  // for boost::is_any_of, boost::split, boost::token_compress_on, boost::trim
-#include <boost/filesystem.hpp>  // for boost::filesystem::create_directories, boost::filesystem::exists, boost::filesystem::path, boost::filesystem::path::extension
 
 using namespace pcl;
 
@@ -87,7 +87,7 @@ struct ScanParameters
 vtkPolyData*
 loadDataSet (const char* file_name)
 {
-  std::string extension = boost::filesystem::path (file_name).extension ().string ();
+  std::string extension = pcl_fs::path (file_name).extension ().string ();
   if (extension == ".ply")
   {
     vtkPLYReader* reader = vtkPLYReader::New ();
@@ -413,10 +413,10 @@ main (int argc, char** argv)
 
     const std::string output_dir = st.at (st.size () - 1) + "_output";
 
-    boost::filesystem::path outpath (output_dir);
-    if (!boost::filesystem::exists (outpath))
+    pcl_fs::path outpath (output_dir);
+    if (!pcl_fs::exists (outpath))
     {
-      if (!boost::filesystem::create_directories (outpath))
+      if (!pcl_fs::create_directories (outpath))
       {
         PCL_ERROR ("Error creating directory %s.\n", output_dir.c_str ());
         return (-1);
