@@ -37,14 +37,21 @@
  */
 
 #pragma once
+
 #include <vtkSmartPointer.h>
 #include <vtkPoints.h>
 #include <vtkPolygon.h>
 #include <vtkUnstructuredGrid.h>
 
-////////////////////////////////////////////////////////////////////////////////////////////
+
+namespace pcl
+{
+
+namespace visualization
+{
+
 template <typename PointT> vtkSmartPointer<vtkDataSet> 
-pcl::visualization::createPolygon (const typename pcl::PointCloud<PointT>::ConstPtr &cloud)
+createPolygon (const typename pcl::PointCloud<PointT>::ConstPtr &cloud)
 {
   vtkSmartPointer<vtkUnstructuredGrid> poly_grid;
   if (cloud->points.empty ())
@@ -53,12 +60,12 @@ pcl::visualization::createPolygon (const typename pcl::PointCloud<PointT>::Const
   vtkSmartPointer<vtkPoints> poly_points = vtkSmartPointer<vtkPoints>::New ();
   vtkSmartPointer<vtkPolygon> polygon    = vtkSmartPointer<vtkPolygon>::New ();
 
-  poly_points->SetNumberOfPoints (cloud->points.size ());
-  polygon->GetPointIds ()->SetNumberOfIds (cloud->points.size ());
+  poly_points->SetNumberOfPoints (cloud->size ());
+  polygon->GetPointIds ()->SetNumberOfIds (cloud->size ());
 
-  for (std::size_t i = 0; i < cloud->points.size (); ++i)
+  for (std::size_t i = 0; i < cloud->size (); ++i)
   {
-    poly_points->SetPoint (i, cloud->points[i].x, cloud->points[i].y, cloud->points[i].z);
+    poly_points->SetPoint (i, (*cloud)[i].x, (*cloud)[i].y, (*cloud)[i].z);
     polygon->GetPointIds ()->SetId (i, i);
   }
 
@@ -70,9 +77,9 @@ pcl::visualization::createPolygon (const typename pcl::PointCloud<PointT>::Const
   return (poly_grid);
 }
 
-////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT> vtkSmartPointer<vtkDataSet> 
-pcl::visualization::createPolygon (const pcl::PlanarPolygon<PointT> &planar_polygon)
+createPolygon (const pcl::PlanarPolygon<PointT> &planar_polygon)
 {
   vtkSmartPointer<vtkUnstructuredGrid> poly_grid;
   if (planar_polygon.getContour ().empty ())
@@ -86,19 +93,19 @@ pcl::visualization::createPolygon (const pcl::PlanarPolygon<PointT> &planar_poly
 
   for (std::size_t i = 0; i < planar_polygon.getContour ().size (); ++i)
   {
-    poly_points->SetPoint (i, planar_polygon.getContour ()[i].x, 
-                              planar_polygon.getContour ()[i].y, 
+    poly_points->SetPoint (i, planar_polygon.getContour ()[i].x,
+                              planar_polygon.getContour ()[i].y,
                               planar_polygon.getContour ()[i].z);
     polygon->GetPointIds ()->SetId (i, i);
   }
 
   std::size_t closingContourId = planar_polygon.getContour ().size ();
   auto firstContour = planar_polygon.getContour ()[0];
-  poly_points->SetPoint (closingContourId, firstContour.x, 
-                                           firstContour.y, 
+  poly_points->SetPoint (closingContourId, firstContour.x,
+                                           firstContour.y,
                                            firstContour.z);
   polygon->GetPointIds ()->SetId (closingContourId, closingContourId);
-  
+
   allocVtkUnstructuredGrid (poly_grid);
   poly_grid->Allocate (1, 1);
   poly_grid->InsertNextCell (polygon->GetCellType (), polygon->GetPointIds ());
@@ -107,3 +114,6 @@ pcl::visualization::createPolygon (const pcl::PlanarPolygon<PointT> &planar_poly
   return (poly_grid);
 }
 
+} // namespace visualization
+} // namespace pcl
+
