@@ -38,6 +38,7 @@
 
 #pragma once
 
+#include <pcl/memory.h>
 #include <pcl/pcl_macros.h>
 #include <pcl/point_types.h>
 #include <pcl/console/print.h>
@@ -559,7 +560,7 @@ namespace pcl
         bool
         wasStopped () const { return (stopped_); }
 
-        /** \brief Stop the interaction and close the visualizaton window. */
+        /** \brief Stop the interaction and close the visualization window. */
         void
         close ()
         {
@@ -919,7 +920,7 @@ namespace pcl
       protected: // types
         struct ExitMainLoopTimerCallback : public vtkCommand
         {
-          ExitMainLoopTimerCallback () : right_timer_id (), window () {}
+          ExitMainLoopTimerCallback () = default;
 
           static ExitMainLoopTimerCallback* New ()
           {
@@ -935,12 +936,12 @@ namespace pcl
               return;
             window->interactor_->TerminateApp ();
           }
-          int right_timer_id;
-          ImageViewer* window;
+          int right_timer_id{0};
+          ImageViewer* window{nullptr};
         };
         struct ExitCallback : public vtkCommand
         {
-          ExitCallback () : window () {}
+          ExitCallback () = default;
 
           static ExitCallback* New ()
           {
@@ -954,14 +955,14 @@ namespace pcl
             window->stopped_ = true;
             window->interactor_->TerminateApp ();
           }
-          ImageViewer* window;
+          ImageViewer* window{nullptr};
         };
 
     private:
         /** \brief Internal structure describing a layer. */
         struct Layer
         {
-          Layer () {}
+          Layer () = default;
           vtkSmartPointer<vtkContextActor> actor;
           std::string layer_name;
         };
@@ -1008,13 +1009,13 @@ namespace pcl
         boost::shared_array<unsigned char> data_;
   
         /** \brief The data array (representing the image) size. Used internally. */
-        std::size_t data_size_;
+        std::size_t data_size_{0};
 
         /** \brief Set to false if the interaction loop is running. */
-        bool stopped_;
+        bool stopped_{false};
 
         /** \brief Global timer ID. Used in destructor only. */
-        int timer_id_;
+        int timer_id_{0};
 
         // /** \brief Internal blender used to overlay 2D geometry over the image. */
         // vtkSmartPointer<vtkImageBlend> blend_;
@@ -1028,7 +1029,7 @@ namespace pcl
         /** \brief Internal data array. Used everytime add***Image is called. 
           * Cleared, everytime the render loop is executed. 
           */
-        std::vector<unsigned char*> image_data_;
+        std::vector<unsigned char*> image_data_{};
 
         struct LayerComparator
         {
