@@ -56,8 +56,7 @@ using namespace std::chrono_literals;
 //////////////////////////////////////////////////////////////////////////////////////////////
 pcl::visualization::PCLHistogramVisualizer::PCLHistogramVisualizer () : 
   exit_main_loop_timer_callback_ (vtkSmartPointer<ExitMainLoopTimerCallback>::New ()), 
-  exit_callback_ (vtkSmartPointer<ExitCallback>::New ()), 
-  stopped_ ()
+  exit_callback_ (vtkSmartPointer<ExitCallback>::New ())
 {
 }
 
