@@ -53,7 +53,9 @@
 #include <vtkPlot.h>
 #include <vtkTable.h>
 
+#include <algorithm>
 #include <fstream>
+#include <limits>
 
 #include <pcl/visualization/pcl_plotter.h>
 
@@ -62,14 +64,12 @@
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 pcl::visualization::PCLPlotter::PCLPlotter (char const *name)
+  : view_ (vtkSmartPointer<vtkContextView>::New ())
+  , chart_(vtkSmartPointer<vtkChartXY>::New())
+  , color_series_(vtkSmartPointer<vtkColorSeries>::New ())
+  , exit_loop_timer_(vtkSmartPointer<ExitMainLoopTimerCallback>::New ())
+  , exit_callback_(vtkSmartPointer<ExitCallback>::New ())
 {
-  //constructing
-  view_ = vtkSmartPointer<vtkContextView>::New ();
-  chart_=vtkSmartPointer<vtkChartXY>::New();
-  color_series_ = vtkSmartPointer<vtkColorSeries>::New ();
-  exit_loop_timer_ = vtkSmartPointer<ExitMainLoopTimerCallback>::New ();
-  exit_callback_ = vtkSmartPointer<ExitCallback>::New ();
-  
   //connecting and mandatory bookkeeping
   view_->GetScene ()->AddItem (chart_);
   view_->GetRenderWindow ()->SetWindowName (name);
@@ -90,7 +90,7 @@ pcl::visualization::PCLPlotter::PCLPlotter (char const *name)
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-pcl::visualization::PCLPlotter::~PCLPlotter() {}
+pcl::visualization::PCLPlotter::~PCLPlotter() = default;
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 void
@@ -105,9 +105,9 @@ pcl::visualization::PCLPlotter::addPlotData (
   //creating a permanent copy of the arrays
   double *permanent_X = new double[size];
   double *permanent_Y = new double[size];
-  memcpy(permanent_X, array_X, size*sizeof(double));
-  memcpy(permanent_Y, array_Y, size*sizeof(double));
-  
+  std::copy(array_X, array_X + size, permanent_X);
+  std::copy(array_Y, array_Y + size, permanent_Y);
+
   //transforming data to be fed to the vtkChartXY
   VTK_CREATE (vtkTable, table);
 
@@ -145,7 +145,7 @@ pcl::visualization::PCLPlotter::addPlotData (
     int type /* = vtkChart::LINE */, 
     std::vector<char> const &color)
 {
-  this->addPlotData (&array_X[0], &array_Y[0], static_cast<unsigned long> (array_X.size ()), name, type, (color.empty ()) ? nullptr : &color[0]);
+  this->addPlotData (array_X.data(), array_Y.data(), static_cast<unsigned long> (array_X.size ()), name, type, (color.empty ()) ? nullptr : color.data());
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -164,7 +164,9 @@ pcl::visualization::PCLPlotter::addPlotData (
     array_x[i] = plot_data[i].first;
     array_y[i] = plot_data[i].second;
   }
-  this->addPlotData (array_x, array_y, static_cast<unsigned long> (plot_data.size ()), name, type, (color.empty ()) ? nullptr : &color[0]);
+  this->addPlotData (array_x, array_y, static_cast<unsigned long> (plot_data.size ()), name, type, (color.empty ()) ? nullptr : color.data());
+  delete[] array_x;
+  delete[] array_y;
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -207,7 +209,7 @@ pcl::visualization::PCLPlotter::addPlotData (
   {
     double xval = i*incr + x_min;
     double yval = compute(r_function, xval);
-    //if (yval == DBL_MAX) continue; //handling dived by zero 
+    //if (yval == std::numeric_limits<double>::max()) continue; //handling dived by zero
     
     array_x[i] = xval;
     array_y[i] = yval;
@@ -260,7 +262,7 @@ pcl::visualization::PCLPlotter::addPlotData (
   while (ss >> temp)
     pnames.push_back(temp);
     
-  int nop = int (pnames.size ());// number of plots (y coordinate vectors)  
+  int nop = static_cast<int>(pnames.size ());// number of plots (y coordinate vectors)  
   
   std::vector<double> xarray;      //array of X coordinates
   std::vector< std::vector<double> > yarrays (nop); //a set of array of Y coordinates
@@ -610,8 +612,8 @@ pcl::visualization::PCLPlotter::computeHistogram (
   {
     if (std::isfinite (value))
     {
-      unsigned int index = (unsigned int) (std::floor ((value - min) / size));
-      if (index == (unsigned int) nbins) index = nbins - 1; //including right boundary
+      auto index = static_cast<unsigned int>(std::floor ((value - min) / size));
+      if (index == static_cast<unsigned int>(nbins)) index = nbins - 1; //including right boundary
       histogram[index].second++;
     }
   }
@@ -636,7 +638,7 @@ pcl::visualization::PCLPlotter::compute (RationalFunction const & r_function, do
   PolynomialFunction numerator = r_function.first, denominator = r_function.second;
   
   double dres = this->compute (denominator,val);
-  //if (dres == 0) return DBL_MAX;  //return the max possible double value to represent infinity
+  //if (dres == 0) return std::numeric_limits<double>::max();  //return the max possible double value to represent infinity
   double nres = this->compute (numerator,val);
   return (nres/dres);
 }
